@@ -19,6 +19,8 @@ assign("elapsedTime", 0, envir = .pracmaEnv)
     environment(.pracmaEnv) <- asNamespace("pracma")
 
     packageStartupMessage(
-        "pracma 1.2.5 (HwB 2012) Practical Numerical Math Functions"
-    )
+        paste("pracma Package Version 1.3.1\n",
+              "Practical Numerical Math Functions\n",
+              "Copyright (c) 2010-2012 Hans W Borchers\n",
+        sep='', collapse=''))
 }
